/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0 - HumanResources\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "You do not have admin rights on HumanResources"
: "You do not have admin rights on HumanResources"

, "Working time model"
: "Working time model"

, "Book as vacation"
: "Book as vacation"

, "Sickness"
: "Sickness"

, "Sickness Days"
: "Sickness Days"

, "Vacation"
: "Vacation"

, "Vacation Days"
: "Vacation Days"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: "There could not be found any {0}. Please try to change your filter-criteria or view-options."

, "Could not book as vacation"
: "Could not book as vacation"

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: "The unexcused sickness days could not be booked as vacation. There are not enough days left!"

, "Human Resources, Human Resources"
: [
  "Human Resources"
 ,"Human Resources"

]
, "Title"
: "Title"

, "Work Start"
: "Work Start"

, "Work End"
: "Work End"

, "Edit {0} for {1} - {2}"
: "Edit {0} for {1} - {2}"

, "Extra free time, Extra free times"
: [
  "Extra free time"
 ,"Extra free times"

]
, "Summary"
: "Summary"

, "Free Times"
: "Free Times"

, "Possible vaction days"
: "Possible vaction days"

, "Remaining vaction days"
: "Remaining vaction days"

, "Taken vaction days"
: "Taken vaction days"

, "Expired vaction days"
: "Expired vaction days"

, "Rebooked vaction days"
: "Rebooked vaction days"

, "Excused sickness days"
: "Excused sickness days"

, "Unexcused sickness days"
: "Unexcused sickness days"

, "Working Time"
: "Working Time"

, "Days to work"
: "Days to work"

, "Hours to work"
: "Hours to work"

, "Days to work after vacation and sickness"
: "Days to work after vacation and sickness"

, "Hours to work after vacation and sickness"
: "Hours to work after vacation and sickness"

, "Miscellaneous"
: "Miscellaneous"

, "Description"
: "Description"

, "Working time Model"
: "Working time Model"

, "Work start"
: "Work start"

, "not set"
: "not set"

, "Work end"
: "Work end"

, "Working Hours per week"
: "Working Hours per week"

, "Mon."
: "Mon."

, "Tue."
: "Tue."

, "Wed."
: "Wed."

, "Thu."
: "Thu."

, "Fri."
: "Fri."

, "Sat."
: "Sat."

, "Sun."
: "Sun."

, "Employee, Employees"
: [
  "Employee"
 ,"Employees"

]
, "Cancel"
: "Cancel"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: "Please use the following format: MM-DD"

, "Calendar"
: "Calendar"

, "Calendars"
: "Calendars"

, "Vacation expires"
: "Vacation expires"

, "Breaks"
: "Breaks"

, "Hours"
: "Hours"

, "Break duration"
: "Break duration"

, "Book remaining vacation"
: "Book remaining vacation"

, "Year"
: "Year"

, "Please enter the year you want to create accounts for:"
: "Please enter the year you want to create accounts for:"

, "Accounts have been created"
: "Accounts have been created"

, "{0} accounts for the year {1} have been created successfully!"
: "{0} accounts for the year {1} have been created successfully!"

, "Create new accounts"
: "Create new accounts"

, "Booking has been successfull!"
: "Booking has been successfull!"

, "The remaining vacation days of the selected accounts have been booked successfully!"
: "The remaining vacation days of the selected accounts have been booked successfully!"

, "CostCenter, CostCenters"
: [
  "CostCenter"
 ,"CostCenters"

]
, "Cost Center, Cost Centers"
: [
  "Cost Center"
 ,"Cost Centers"

]
, "Startdate"
: "Startdate"

, "Contract, Contracts"
: [
  "Contract"
 ,"Contracts"

]
, "Vacation in same period"
: "Vacation in same period"

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."

, "Edit {0}"
: "Edit {0}"

, "Start Date"
: "Start Date"

, "End Date"
: "End Date"

, "Feast Calendar"
: "Feast Calendar"

, "Choose the template"
: "Choose the template"

, "Vacation days of one calendar year"
: "Vacation days of one calendar year"

, "Edit {0} \"{1}\""
: "Edit {0} \"{1}\""

, "Edit {0} for {1}"
: "Edit {0} for {1}"

, "Add {0} for {1}"
: "Add {0} for {1}"

, "You have to select at least one day to save this sickness entry."
: "You have to select at least one day to save this sickness entry."

, "You have to select at least one day to save this vacation entry."
: "You have to select at least one day to save this vacation entry."

, "No day selected"
: "No day selected"

, "Personal account, Personal accounts"
: [
  "Personal account"
 ,"Personal accounts"

]
, "Status"
: "Status"

, "Remaining"
: "Remaining"

, "Select Days"
: "Select Days"

, "Enter description"
: "Enter description"

, "Account is disabled or deleted!"
: "Account is disabled or deleted!"

, "Division"
: "Division"

, "Health Insurance"
: "Health Insurance"

, "Apply contact data on form"
: "Apply contact data on form"

, "Salutation"
: "Salutation"

, "Personal Information"
: "Personal Information"

, "Country"
: "Country"

, "Birthday"
: "Birthday"

, "Internal Information"
: "Internal Information"

, "Banking Information"
: "Banking Information"

, "Days"
: "Days"

, "Type"
: "Type"

, "Expiration date"
: "Expiration date"

, "WK"
: "WK"

, "Loading calendar data..."
: "Loading calendar data..."

, "Year can not be changed"
: "Year can not be changed"

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: "You have already selected some dates from another year. Please create a new record to add dates from another year!"

, "No more vacation days"
: "No more vacation days"

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."

, "Excused"
: "Excused"

, "Unexcused"
: "Unexcused"

, "Currently employed"
: "Currently employed"

, "Employees which are currently employed"
: "Employees which are currently employed"

, "All employees"
: "All employees"

, "All available employees"
: "All available employees"

, "Payed"
: "Payed"

, "Not payed"
: "Not payed"

, "Currently employed employees"
: "Currently employed employees"

, "All accounts"
: "All accounts"

, "All available accounts"
: "All available accounts"

, "Full-time 40 hours"
: "Full-time 40 hours"

, "Full-time 37.5 hours"
: "Full-time 37.5 hours"

, "Part-time 20 hours"
: "Part-time 20 hours"

, "Freetime Type"
: "Freetime Type"

, "Possible free time definitions"
: "Possible free time definitions"

, "Vacation Status"
: "Vacation Status"

, "Possible vacation status definitions"
: "Possible vacation status definitions"

, "Requested"
: "Requested"

, "In process"
: "In process"

, "Accepted"
: "Accepted"

, "Declined"
: "Declined"

, "Sickness Status"
: "Sickness Status"

, "Possible sickness status definitions"
: "Possible sickness status definitions"

, "Default Feast Calendar"
: "Default Feast Calendar"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Here you can define the default feast calendar used to set feast days and other free days in datepicker"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in HumanResources Application."
: "Enabled Features in HumanResources Application."

, "Calculate Daily Reports"
: "Calculate Daily Reports"

, "Activate to calculate daily reports with a nightly scheduler job"
: "Activate to calculate daily reports with a nightly scheduler job"

, "Extra freetime type"
: "Extra freetime type"

, "Possible extra free time definitions"
: "Possible extra free time definitions"

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."

, "Report Templates Node ID"
: "Report Templates Node ID"

, "Timetracker Timeaccount for Workingtime Tracking"
: "Timetracker Timeaccount for Workingtime Tracking"

, "Daily Working Time Report, Daily Working Time Reports"
: [
  "Daily Working Time Report"
 ,"Daily Working Time Reports"

]
, "Date"
: "Date"

, "Evaluation Start Time"
: "Evaluation Start Time"

, "Evaluation End Time"
: "Evaluation End Time"

, "Paid Absence Time"
: "Paid Absence Time"

, "Unpaid Absence Time"
: "Unpaid Absence Time"

, "Absence"
: "Absence"

, "Break Time Net"
: "Break Time Net"

, "Break Deduction Time"
: "Break Deduction Time"

, "Feast Time"
: "Feast Time"

, "Break Time"
: "Break Time"

, "Sickness Time"
: "Sickness Time"

, "Working Time Correction"
: "Working Time Correction"

, "Actual Working Time"
: "Actual Working Time"

, "Target Working Time"
: "Target Working Time"

, "System Remark"
: "System Remark"

, "Remark"
: "Remark"

, "Is Cleared"
: "Is Cleared"

, "Cleared in"
: "Cleared in"

, "Working time, Working times"
: [
  "Working time"
 ,"Working times"

]
, "Quick search"
: "Quick search"

, "Extra free times"
: "Extra free times"

, "Free Time, Free Times"
: [
  "Free Time"
 ,"Free Times"

]
, "Account"
: "Account"

, "First Day"
: "First Day"

, "Last Day"
: "Last Day"

, "Days Count"
: "Days Count"

, "Free Days"
: "Free Days"

, "Private Information"
: "Private Information"

, "Is employed"
: "Is employed"

, "Number"
: "Number"

, "Badge Id"
: "Badge Id"

, "Germany"
: "Germany"

, "Locality"
: "Locality"

, "Postalcode"
: "Postalcode"

, "Region"
: "Region"

, "Street"
: "Street"

, "Street 2"
: "Street 2"

, "E-Mail"
: "E-Mail"

, "Telephone Number"
: "Telephone Number"

, "Cell Phone Number"
: "Cell Phone Number"

, "Last Name"
: "Last Name"

, "First Name"
: "First Name"

, "Employee name"
: "Employee name"

, "Account Holder"
: "Account Holder"

, "Account Number"
: "Account Number"

, "Bank Name"
: "Bank Name"

, "Code Number"
: "Code Number"

, "Employment begin"
: "Employment begin"

, "Employment end"
: "Employment end"

, "Supervisor"
: "Supervisor"

, "Profession"
: "Profession"

, "Position"
: "Position"

, "Contracts"
: "Contracts"

, "Cost Centers"
: "Cost Centers"

, "Free Day, Free Days"
: [
  "Free Day"
 ,"Free Days"

]
, "Break, Breaks"
: [
  "Break"
 ,"Breaks"

]
, "Workingtime"
: "Workingtime"

, "No contract could be found."
: "No contract could be found."

, "Please create a contract for this employee!"
: "Please create a contract for this employee!"

, "Negative Timespace"
: "Negative Timespace"

, "The start date of the contract must be before the end date!"
: "The start date of the contract must be before the end date!"

, "Not allowed!"
: "Not allowed!"

, "It's only allowed to book remaining vacation days from years in the past!"
: "It's only allowed to book remaining vacation days from years in the past!"

, "Contracts overlap"
: "Contracts overlap"

, "The contracts must not overlap!"
: "The contracts must not overlap!"

, "No or no valid year given"
: "No or no valid year given"

, "Please use a valid year!"
: "Please use a valid year!"

, "No current contract!"
: "No current contract!"

, "A current contract could not be found!"
: "A current contract could not be found!"

, "Contract not editable"
: "Contract not editable"

, "You are not allowed to change the record if a vacation has been booked already!"
: "You are not allowed to change the record if a vacation has been booked already!"

, "No personal account found"
: "No personal account found"

, "An existing personal account could not be found. Please create one!"
: "An existing personal account could not be found. Please create one!"

, "edit private employee data"
: "edit private employee data"

, "Edit birthday, account data and other private information of employee records"
: "Edit birthday, account data and other private information of employee records"

, "Public Holiday Calendar"
: "Public Holiday Calendar"

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"

, "Public Holidays"
: "Public Holidays"

, "Badge ID"
: "Badge ID"

, "Quick Search"
: "Quick Search"

, "Full Name"
: "Full Name"

, "Street2"
: "Street2"

, "Wage types"
: "Wage types"

, "Free time types"
: "Free time types"

, "Working time scheme, Working time schemes"
: [
  "Working time scheme"
 ,"Working time schemes"

]
, "Template"
: "Template"

, "Individual"
: "Individual"

, "Shared"
: "Shared"

, "Calculate all Reports"
: "Calculate all Reports"

, "Recalculate"
: "Recalculate"

, "Working Time Rules"
: "Working Time Rules"

, "Working Time Schema"
: "Working Time Schema"

, "Template (individual working time schemas are created for each contract)"
: "Template (individual working time schemas are created for each contract)"

, "Shared (this working time schemas can be shared among contracts)"
: "Shared (this working time schemas can be shared among contracts)"

, "Default wage type"
: "Default wage type"

, "Salary"
: "Salary"

, "Business trip"
: "Business trip"

, "Sunday bonus"
: "Sunday bonus"

, "Feast day"
: "Feast day"

, "Feast day bonus"
: "Feast day bonus"

, "Overtime"
: "Overtime"

, "Overtime bonus"
: "Overtime bonus"

, "Late shift bonus"
: "Late shift bonus"

, "Night bonus"
: "Night bonus"

, "Stand by"
: "Stand by"

, "Unpaid"
: "Unpaid"

, "[S] Sickness"
: "[S] Sickness"

, "[D] Visit doctor"
: "[D] Visit doctor"

, "[V] Vacation"
: "[V] Vacation"

, "[BT] Business trip"
: "[BT] Business trip"

, "[FT] Flex time"
: "[FT] Flex time"

, "[BK] Break"
: "[BK] Break"

, "[T] Training"
: "[T] Training"

, "No valid contract for this date"
: "No valid contract for this date"

, "unexpected error: "
: "unexpected error: "

, "daily wt reports can't be created"
: "daily wt reports can't be created"

, "It is not allowed to update a cleared report"
: "It is not allowed to update a cleared report"

, "monthly wt reports can't be created"
: "monthly wt reports can't be created"

, "previous months need to be cleared first"
: "previous months need to be cleared first"

, "following months need to be uncleared first"
: "following months need to be uncleared first"

, "Corrected Evaluation Start Time"
: "Corrected Evaluation Start Time"

, "Corrected Evaluation End Time"
: "Corrected Evaluation End Time"

, "Target Working Time Correction"
: "Target Working Time Correction"

, "Working Times"
: "Working Times"

, "Total Working Time"
: "Total Working Time"

, "Calculation Error"
: "Calculation Error"

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  "Monthly Working Time Report"
 ,"Monthly Working Time Reports"

]
, "Month"
: "Month"

, "Daily Working Time Reports"
: "Daily Working Time Reports"

, "Working Time Balance Previous Month"
: "Working Time Balance Previous Month"

, "Total Working Time Balance"
: "Total Working Time Balance"

, "Wage type, Wage types"
: [
  "Wage type"
 ,"Wage types"

]
, "Abbreviation"
: "Abbreviation"

, "Name"
: "Name"

, "System"
: "System"

, "Factor (%)"
: "Factor (%)"

, "Additional Wage"
: "Additional Wage"

, "Start time"
: "Start time"

, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."

, "Time worked"
: "Time worked"

, "Break time"
: "Break time"

, "Work Time Limit, Work Time Limits"
: [
  "Work Time Limit"
 ,"Work Time Limits"

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."

, "Absence reason, Absence reasons"
: [
  "Absence reason"
 ,"Absence reasons"

]
, "Allow Booking"
: "Allow Booking"

, "Allow Planning"
: "Allow Planning"

, "Enable Freetime Timetracking"
: "Enable Freetime Timetracking"

, "Timeaccount"
: "Timeaccount"

, "Transponder Id"
: "Transponder Id"

, "Human Resources"
: "Human Resources"

, "Extra free time"
: "Extra free time"

, "Employee"
: "Employee"

, "CostCenter"
: "CostCenter"

, "Cost Center"
: "Cost Center"

, "Contract"
: "Contract"

, "Personal account"
: "Personal account"

, "Daily Working Time Report"
: "Daily Working Time Report"

, "Working time"
: "Working time"

, "Free Time"
: "Free Time"

, "Free Day"
: "Free Day"

, "Break"
: "Break"

, "Working time scheme"
: "Working time scheme"

, "Monthly Working Time Report"
: "Monthly Working Time Report"

, "Wage type"
: "Wage type"

, "Work Time Limit"
: "Work Time Limit"

, "Absence reason"
: "Absence reason"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
